@@ -51,11 +51,13 @@ class AlchemyJsonApiViewBuilder:
         '_before_list_callback': {'kwarg': None, 'default': None},
         '_after_list_callback': {'kwarg': None, 'default': None},
         '_before_get_response': {'kwarg': None, 'default': None},
+        '_after_serialization': {'kwarg': None, 'default': None},
         '_relations': {'kwarg': None, 'default': []},
         '_custom_fields': {'kwarg': None, 'default': {}},
         '_computed_filters': {'kwarg': None, 'default': {}},
         '_api_version': {'kwarg': 'api_version', 'default': ''},
         '_is_admin': {'kwarg': 'is_admin', 'default': False},
+        '_always_include': {'kwarg': 'always_include', 'default': False},
         '_skip_plugins': {'kwarg': 'skip_plugins', 'default': []},
         '_plugin_options': {'kwarg': 'plugin_options', 'default': {}},
     }
@@ -76,7 +78,8 @@ class AlchemyJsonApiViewBuilder:
                  include_plugins: Optional[Sequence[str]] = None,
                  plugin_options: Optional[Dict[str, Any]] = None,
                  custom_field_handlers: Optional[Dict[Type, Callable]] = None,
-                 is_admin: Optional[bool] = False):
+                 is_admin: Optional[bool] = False,
+                 always_include: Optional[bool] = False):
         self.override(
             alchemy_model=alchemy_model,
             resource_name=resource_name,
@@ -94,6 +97,7 @@ class AlchemyJsonApiViewBuilder:
             plugin_options=plugin_options,
             custom_field_handlers=custom_field_handlers,
             is_admin=is_admin,
+            always_include=always_include,
         )
 
     @staticmethod
@@ -116,7 +120,8 @@ class AlchemyJsonApiViewBuilder:
                  include_plugins: Optional[Sequence[str]] = None,
                  plugin_options: Optional[Dict[str, Any]] = None,
                  custom_field_handlers: Optional[Dict[Type, Callable]] = None,
-                 is_admin: Optional[bool] = False) -> 'AlchemyJsonApiViewBuilder':
+                 is_admin: Optional[bool] = False,
+                 always_include: Optional[bool] = False) -> 'AlchemyJsonApiViewBuilder':
 
         _locals = locals()
         for attribute, settings in self.ATTRIBUTES.items():
@@ -137,6 +142,10 @@ class AlchemyJsonApiViewBuilder:
     def is_admin(self) -> bool:
         return self._is_admin
 
+    @property
+    def always_include(self) -> bool:
+        return self._always_include
+
     def __warn_if_method_not_available(self, method: str):
         if method not in self._allowed_methods:
             LOGGER.warning(
@@ -194,6 +203,11 @@ class AlchemyJsonApiViewBuilder:
         self.__warn_if_method_not_available(json_api_spec_http_methods.HTTP_GET)
         return self
 
+    def after_serialization(self, after_serialization: Callable[[Any], Any] = None) -> 'AlchemyJsonApiViewBuilder':
+        self._after_serialization = after_serialization
+        self.__warn_if_method_not_available(json_api_spec_http_methods.HTTP_GET)
+        return self
+
     def add_relation(self, field: str,
                      model: Type,
                      resource_name: str,
@@ -343,6 +357,10 @@ class AlchemyJsonApiViewBuilder:
                     return [{'errors': [str(e)]}], [], 0, getattr(e, 'http_status', HTTP_500_INTERNAL_SERVER_ERROR)
 
             result = schema_many.json_api_dump(objects, self._resource_name)
+
+            if self._after_serialization:
+                result, rendered_includes = self._after_serialization(result, rendered_includes)
+
             return result, rendered_includes, pagination.total_results, HTTP_200_OK
 
         def object_create(request, data, *args, **kwargs) -> Tuple[Dict, str, int]:
@@ -441,6 +459,7 @@ class AlchemyJsonApiViewBuilder:
                                              permission_classes=self._permission_classes,
                                              authentication_classes=self._authentication_classes,
                                              is_admin=self._is_admin,
+                                             always_include=self._always_include,
                                              page_size=self._page_size,
                                              raw_items=True)
 
